==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolCommandArgumentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandArgumentDescription } from "./ToolCommandArgumentDescription";
/**
 * @hidden
 */
export let ToolCommandArgumentDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolCommandArgumentDescriptionMetadata extends Base {
        static b(a) {
            if (ToolCommandArgumentDescriptionMetadata.a == null) {
                ToolCommandArgumentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolCommandArgumentDescriptionMetadata.c(ToolCommandArgumentDescriptionMetadata.a);
            }
            if (a.j(ToolCommandArgumentDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolCommandArgumentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ArgumentName", "String");
            a.item("Value", "Unknown");
        }
        static d(a) {
            ToolCommandArgumentDescriptionMetadata.b(a);
            a.aa("ToolCommandArgument", () => new ToolCommandArgumentDescription());
            a.z("ToolCommandArgument", ToolCommandArgumentDescriptionMetadata.a);
        }
    }
    ToolCommandArgumentDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolCommandArgumentDescriptionMetadata, 'ToolCommandArgumentDescriptionMetadata');
    ToolCommandArgumentDescriptionMetadata.a = null;
    return ToolCommandArgumentDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolCommandArgumentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolCommandArgumentDescription } from "./ToolCommandArgumentDescription";
/**
 * @hidden
 */
export let ToolCommandArgumentDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolCommandArgumentDescriptionMetadata extends Base {
        static b(a) {
            if (ToolCommandArgumentDescriptionMetadata.a == null) {
                ToolCommandArgumentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolCommandArgumentDescriptionMetadata.c(ToolCommandArgumentDescriptionMetadata.a);
            }
            if (a.k(ToolCommandArgumentDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolCommandArgumentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ArgumentName", "String");
            a.item("Value", "Unknown");
        }
        static d(a) {
            ToolCommandArgumentDescriptionMetadata.b(a);
            a.ac("ToolCommandArgument", () => new ToolCommandArgumentDescription());
            a.ab("ToolCommandArgument", ToolCommandArgumentDescriptionMetadata.a);
        }
    }
    ToolCommandArgumentDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolCommandArgumentDescriptionMetadata, 'ToolCommandArgumentDescriptionMetadata');
    ToolCommandArgumentDescriptionMetadata.a = null;
    return ToolCommandArgumentDescriptionMetadata;
})();
